Struct rust_ocpp::v1_6::messages::boot_notification::BootNotificationRequest [−][src]
pub struct BootNotificationRequest {
pub charge_box_serial_number: Option<String>,
pub charge_point_model: String,
pub charge_point_serial_number: Option<String>,
pub charge_point_vendor: String,
pub firmware_version: Option<String>,
pub iccid: Option<String>,
pub imsi: Option<String>,
pub meter_serial_number: Option<String>,
}Fields
charge_box_serial_number: Option<String>From OCPP Specification
Optional. This contains a value that identifies the serial number of the Charge Box inside the Charge Point. Deprecated, will be removed in future version
charge_point_model: StringFrom OCPP Specification
Required. This contains a value that identifies the model of the ChargePoint.
charge_point_serial_number: Option<String>From OCPP Specification
Optional. This contains a value that identifies the serial number of the Charge Point.
charge_point_vendor: StringFrom OCPP Specification
Required. This contains a value that identifies the vendor of the ChargePoint.
firmware_version: Option<String>From OCPP Specification
Optional. This contains the firmware version of the Charge Point.
iccid: Option<String>From OCPP Specification
Optional. This contains the ICCID of the modem’s SIM card.
imsi: Option<String>From OCPP Specification
Optional. This contains the IMSI of the modem’s SIM card.
meter_serial_number: Option<String>From OCPP Specification
Optional. This contains the serial number of the main electrical meter of the Charge Point.