Struct rust_ocpp::v1_6::messages::trigger_message::TriggerMessageResponse [−][src]
pub struct TriggerMessageResponse {
pub status: TriggerMessageStatus,
}Expand description
This contains the field definition of the TriggerMessage.req PDU sent by the Central System to the Charge Point. See also Trigger Message
Fields
status: TriggerMessageStatusRequired. Indicates whether the Charge Point will send the requested notification or not.