Enum rust_ocpp::v1_6::types::AvailabilityStatus [−][src]
pub enum AvailabilityStatus {
Accepted,
Rejected,
Scheduled,
}Expand description
Status returned in response to ChangeAvailabilityRequest
Variants
Request has been accepted and will be executed.
Request has not been accepted and will not be executed.
Request has been accepted and will be executed when transaction(s) in progress have finished.