Enum rust_ocpp::v1_6::types::ConfigurationStatus [−][src]
pub enum ConfigurationStatus {
Accepted,
Rejected,
RebootRequired,
NotSupported,
}Variants
From OCPP Specification
Configuration key is supported and setting has been changed.
From OCPP Specification
Configuration key is supported, but setting could not be changed.
From OCPP Specification
Configuration key is supported and setting has been changed, but change will be available after reboot (Charge Point will not reboot itself)
From OCPP Specification
Configuration key is not supported.