Enum rust_ocpp::v1_6::types::Phase [−][src]
pub enum Phase {
L1,
L2,
L3,
N,
L1N,
L2N,
L3N,
L1L2,
L2L3,
L3L1,
}Expand description
Phase as used in SampledValue. Phase specifies how a measured value is to be interpreted. Please note that not all values of Phase are applicable to all Measurands.
Variants