Enum rust_ocpp::v1_6::types::ReadingContext [−][src]
pub enum ReadingContext {
InterruptionBegin,
InterruptionEnd,
Other,
SampleClock,
SamplePeriodic,
TransactionBegin,
TransactionEnd,
Trigger,
}Expand description
Values of the context field of a value in SampledValue.
Variants
Value taken at start of interruption.
Value taken when resuming after interruption.
Value for any other situations.
Value taken at clock aligned interval.
Value taken as periodic sample relative to start time of transaction.
Value taken at start of transaction.
Value taken at end of transaction.
Value taken in response to a TriggerMessage.req