Enum rust_ocpp::v1_6::types::Reason [−][src]
pub enum Reason {
DeAuthorized,
EmergencyStop,
EVDisconnected,
HardReset,
Local,
Other,
PowerLoss,
Reboot,
Remote,
SoftReset,
UnlockCommand,
}Expand description
Reason for stopping a transaction in StopTransactionRequest
Variants
The transaction was stopped because of the authorization status in a StartTransaction.conf
Emergency stop button was used.
disconnecting of cable, vehicle moved away from inductive charge unit.
A hard reset command was received.
Stopped locally on request of the user at the Charge Point. This is a regular termination of a transaction. Examples: presenting an RFID tag, pressing a button to stop.
Any other reason.
Complete loss of power.
A locally initiated reset/reboot occurred. (for instance watchdog kicked in)
Stopped remotely on request of the user. This is a regular termination of a transaction. Examples: termination using a smartphone app, exceeding a (non local) prepaid credit.
A soft reset command was received.
Central System sent an Unlock Connector command.