Enum rust_ocpp::v1_6::types::UpdateStatus [−][src]
pub enum UpdateStatus {
Accepted,
Failed,
NotSupported,
VersionMismatch,
}Expand description
Type of update for a SendLocalListRequest
Variants
Local Authorization List successfully updated.
Failed to update the Local Authorization List.
Update of Local Authorization List is not supported by Charge Point.
Version number in the request for a differential update is less or equal then version number of current list.