Enum rust_ocpp::v1_6::types::UpdateType [−][src]
pub enum UpdateType {
Differential,
Full,
}Expand description
Type of update for a SendLocalListRequest
Variants
Indicates that the current Local Authorization List must be updated with the values in this message.
Indicates that the current Local Authorization List must be replaced by the values in this message.